package com.networksByteDesign.util;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.taskdefs.Input;

public class RequiredInput extends Input
{
    /**
     * Defines the name of a property to be created from input. Behavior is
     * according to property task, which means that existing properties
     * cannot be overridden.
     *
     * @param addproperty Name for the property to be created from input
     */
    public void setAddproperty (String addproperty)
    {
        super.setAddproperty(addproperty);
        propertyName      = addproperty;
        havePropertyName  = true;
    }
    
    /**
     * Returns the property that gets set during the build run.
     * @return The property being set.
     */
    public String getProperty()
    {
        return propertyName;
    }

    /**
     * Sets the Error Message which gets displayed to the user during
     * the build run.
     * @param errorMessage The error message to be displayed.
     */
    public void setErrormessage (String errorMessage)
    {
        this.errorMessage = errorMessage;
        haveErrorMessage  = true;
    }

    /**
     * Returns the Error Message which gets displayed to the user during
     * the build run.
     * @return The error message to be displayed.
     */
    public String getErrormessage()
    {
        return errorMessage;
    }

    /**
     * Actual test method executed by jakarta-ant.
     * @exception BuildException
     */
    public void execute () throws BuildException
    {
        if (!havePropertyName)
        {
            throw new BuildException("Missing attribute propertyName",
                                     location);
        }

        if (!haveErrorMessage)
        {
            throw new BuildException("Missing attribute errorMessage",
                                     location);
        }

        super.execute();

        if(getProject().getProperty(propertyName).trim().length() == 0)
        {
            throw new BuildException(errorMessage, location);
        }
    }

    private String  propertyName     = "";
    private String  errorMessage     = "";
    private boolean haveErrorMessage = false;
    private boolean havePropertyName = false;
}
