/*--------------------------------------------------------------------------
   File: salesItemTest
   ------------------------------------------------------------------------*/
package com.networksByteDesign.eMarket.inventory;


// Internal libraries
import com.networksByteDesign.eMarket.inventory.salesItem;

// Third party libraries
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;


public class salesItemTest extends TestCase
{
    ////////////////////////////////////////////////////////////////////////
    // salesItemTest(String)
    ////////////////////////////////////////////////////////////////////////

    /**
     * <p>
     * This is the constructor for the <code>salesItemTest</code>
     * class.  It calls the super class and configures the instance.
     * </p>
     *
     * @param testName the name of the test to construct
     *
     * */
    public salesItemTest(String testName)
    {
        super(testName);
    }

    ////////////////////////////////////////////////////////////////////////
    // main(String[])
    ////////////////////////////////////////////////////////////////////////

    /**
     * <p>
     * This is the mainline for the <code>salesItemTest</code>
     * class.  It runs the test suite that has been established.
     * </p>
     *
     * @param args any command line arguments to the test program
     *
     * */
    public static void main(String[] args)
    {
        junit.textui.TestRunner.run(suite());
    }

    ////////////////////////////////////////////////////////////////////////
    // suite()
    ////////////////////////////////////////////////////////////////////////

    /**
     * <p>
     * This is the static method that defines the specific tests that
     * comprise the unittest.
     * </p>
     *
     * @return the test suite that has been established
     *
     * */
    public static Test suite()
    {
        TestSuite suite = new TestSuite();

        // test constructor()
        suite.addTest(new salesItemTest("testConstructor"));
        suite.addTest(new salesItemTest("testSetter"));

        return suite;
    }

    ////////////////////////////////////////////////////////////////////////
    // testConstructor()
    ////////////////////////////////////////////////////////////////////////

    /**
     * <p>
     * Test for constructing a salesItem object
     * </p>
     *
     * */
    public void testConstructor()
    {
        int id = 123;
        String name = "Router";

        // Does "happy path" work?
        salesItem test1 = new salesItem(id, name);
        assertEquals("Happy Path id test failed", id, test1.getId());
        assertEquals("Happy Path name test failed", name,
            test1.getName());

        // Is negative id handled?
        try
        {
            salesItem test2 = new salesItem(-123, name);
            fail("Expected exception was not thrown");
        }
        catch(IllegalArgumentException e) {}

        // Is zero id handled?
        try
        {
            salesItem test3 = new salesItem(0, name);
            fail("Expected exception was not thrown");
        }
        catch(IllegalArgumentException e) {}

        // Is empty string handled?
        try
        {
            salesItem test4 = new salesItem(id, "");
            fail("Expected exception was not thrown");
        }
        catch(IllegalArgumentException e) {}

        // Is null string handled?
        try
        {
            salesItem test5 = new salesItem(id, null);
            fail("Expected exception was not thrown");
        }
        catch(IllegalArgumentException e) {}
    }

    ////////////////////////////////////////////////////////////////////////
    // testSetter()
    ////////////////////////////////////////////////////////////////////////

    /**
     * <p>
     * Test for setter for the salesItem object
     * </p>
     *
     * */
    public void testSetter()
    {
        int id = 123;
        String name = "Router";
        salesItem test = new salesItem(456, "Another");

        // Does "happy path" work?
        test.setId(id);
        assertEquals("Happy Path id test failed", id, test.getId());

        test.setName(name);
        assertEquals("Happy Path name test failed", name,
            test.getName());

        // Is negative id handled?
        try
        {
            test.setId(-123);
            fail("Expected exception was not thrown");
        }
        catch(IllegalArgumentException e) {}

        // Is zero id handled?
        try
        {
            test.setId(0);
            fail("Expected exception was not thrown");
        }
        catch(IllegalArgumentException e) {}

        // Is empty string handled?
        try
        {
            test.setName("");
            fail("Expected exception was not thrown");
        }
        catch(IllegalArgumentException e) {}

        // Is null string handled?
        try
        {
            test.setName(null);
            fail("Expected exception was not thrown");
        }
        catch(IllegalArgumentException e) {}
    }
}
