/*--------------------------------------------------------------------------
   File: companyTest
   ------------------------------------------------------------------------*/
package com.networksByteDesign.eMarket.inventory;


// Internal libraries
import com.networksByteDesign.eMarket.inventory.company;

// Third party libraries
import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;


public class companyTest extends TestCase
{
    ////////////////////////////////////////////////////////////////////////
    // companyTest(String)
    ////////////////////////////////////////////////////////////////////////

    /**
     * <p>
     * This is the constructor for the <code>companyTest</code>
     * class.  It calls the super class and configures the instance.
     * </p>
     *
     * @param testName the name of the test to construct
     */
    public companyTest(String testName)
    {
        super(testName);
    }

    ////////////////////////////////////////////////////////////////////////
    // main(String[])
    ////////////////////////////////////////////////////////////////////////

    /**
     * <p>
     * This is the mainline for the <code>companyTest</code> class.
     * It runs the test suite that has been established.
     * </p>
     *
     * @param args any command line arguments to the test program
     */
    public static void main(String[] args)
    {
        junit.textui.TestRunner.run(suite());
    }

    ////////////////////////////////////////////////////////////////////////
    // suite()
    ////////////////////////////////////////////////////////////////////////

    /**
     * <p>
     * This is the static method that defines the specific tests that
     * comprise the unittest.
     * </p>
     *
     * @return the test suite that has been established
     */
    public static Test suite()
    {
        TestSuite suite = new TestSuite();

        // test constructor()
        suite.addTest(new companyTest("testConstructor"));
        suite.addTest(new companyTest("testSetter"));

        return suite;
    }

    ////////////////////////////////////////////////////////////////////////
    // testConstructor()
    ////////////////////////////////////////////////////////////////////////

    /**
     * <p>
     * Test for constructing a company object
     * </p>
     */
    public void testConstructor()
    {
        int id = 123;
        String name = "Router";

        // Does "happy path" work?
        company test1 = new company(id, name);
        assertEquals("Happy Path id test failed", id, test1.getId());
        assertEquals("Happy Path name test failed", name,
            test1.getName());

        // Is negative id handled?
        try
        {
            company test2 = new company(-123, name);
            fail("Expected exception was not thrown");
        }
        catch(IllegalArgumentException e) {}

        // Is zero id handled?
        try
        {
            company test3 = new company(0, name);
            fail("Expected exception was not thrown");
        }
        catch(IllegalArgumentException e) {}

        // Is empty string handled?
        try
        {
            company test4 = new company(id, "");
            fail("Expected exception was not thrown");
        }
        catch(IllegalArgumentException e) {}

        // Is null string handled?
        try
        {
            company test5 = new company(id, null);
            fail("Expected exception was not thrown");
        }
        catch(IllegalArgumentException e) {}
    }

    ////////////////////////////////////////////////////////////////////////
    // testSetter()
    ////////////////////////////////////////////////////////////////////////

    /**
     * <p>
     * Test for setter for the company object
     * </p>
     */
    public void testSetter()
    {
        int id = 123;
        String name = "Router";
        company test = new company(456, "Another");

        // Does "happy path" work?
        test.setId(id);
        assertEquals("Happy Path id test failed", id, test.getId());

        test.setName(name);
        assertEquals("Happy Path name test failed", name,
            test.getName());

        // Is negative id handled?
        try
        {
            test.setId(-123);
            fail("Expected exception was not thrown");
        }
        catch(IllegalArgumentException e) {}

        // Is zero id handled?
        try
        {
            test.setId(0);
            fail("Expected exception was not thrown");
        }
        catch(IllegalArgumentException e) {}

        // Is empty string handled?
        try
        {
            test.setName("");
            fail("Expected exception was not thrown");
        }
        catch(IllegalArgumentException e) {}

        // Is null string handled?
        try
        {
            test.setName(null);
            fail("Expected exception was not thrown");
        }
        catch(IllegalArgumentException e) {}
    }
}
